function [I,x,w]=integrazione_gauss_jacobi(N,alpha,beta,a,b,f)
% INPUT:
% N: NUMERO NODI.
% alpha,beta: w(x)=((1-x)^alpha)*((1+x)^beta)
% a,b: SE alpha=0, beta=0, SONO ESTREMI DI INTEGRAZIONE, 
%    ALTRIMENTI a=-1, b=1.
% f: INTEGRANDA (RISPETTO w).
% OUTPUT:
% I: APPROSSIMAZIONE DI \int_a^b f(x) w(x) dx
% x,w: NODI/PESI UTILIZZATI.
ab=r_jacobi(N,alpha,beta); %TERM.RICORSIVI
xw=gauss(N,ab); %NODI/PESI IN MATRICE .
x=xw(:,1);w=xw(:,2);%NODI/PESI GAUSS JAC.[-1,1].
if (alpha == 0) & (beta == 0) & ((a~=-1)|(b~=1))
 x=((a+b)/2)+((b-a)/2)*x;%NODI GAUSS-LEG.[a,b].
 w=((b-a)/2)*w;%PESI GAUSS-LEG.[a,b].
end
fx=feval(f,x);%VALUTAZIONE FUNZIONE.
I=w'*fx;%VALORE INTEGRALE.